@@ -14,9 +14,9 @@ from imswitch.imcommon.model import initLogger
 
 
 class FlatfieldManager(SignalInterface):
-    sigFlatfieldMaskUpdated = Signal(object)  # (maskCombined)
 
     def __init__(self, FlatfieldInfo, *args, **kwargs):
+        self.sigFlatfieldMaskUpdated = Signal(object)  # (maskCombined)  # (maskCombined)
         super().__init__(*args, **kwargs)
         self.__logger = initLogger(self)
 
